#! /bin/sh
cd src
../../../../tools/make1cmfont gribsl10 0
../../../../tools/make1cmfont gribsl10 0.5
../../../../tools/make1cmfont gribsl10 1
../../../../tools/make1cmfont gribsl10 2
../../../../tools/make1cmfont gribsl10 3
../../../../tools/make1cmfont gribsl10 4
../../../../tools/make1cmfont gribsl10 5
../../../../tools/make1cmfont gribsl10 6
../../../../tools/make1cmfont gribyr10 0
../../../../tools/make1cmfont gribyr10 0.5
../../../../tools/make1cmfont gribyr10 1
../../../../tools/make1cmfont gribyr10 2
../../../../tools/make1cmfont gribyr10 3
../../../../tools/make1cmfont gribyr10 4
../../../../tools/make1cmfont gribyr10 5
../../../../tools/make1cmfont gribyr10 6
../../../../tools/make1cmfont gribyr9 0
../../../../tools/make1cmfont gribyr9 1
../../../../tools/make1cmfont gribyr8 0
../../../../tools/make1cmfont gribyr8 1
../../../../tools/make1cmfont gribysl8 0
../../../../tools/make1cmfont gribysl8 1
../../../../tools/make1cmfont gribysl9 0
../../../../tools/make1cmfont gribysl9 1
../../../../tools/make1cmfont grreg10 0
../../../../tools/make1cmfont grreg10 1
../../../../tools/make1cmfont grreg8 0
../../../../tools/make1cmfont grbld10 0
../../../../tools/make1cmfont grtt10 0
../../../../tools/make1cmfont rgrrg10 0
cmmf "\mode=localfont; mag=magstep(0.9);" input rgrrg10
gftopk rgrrg10.*gf
mv rgrrg10.tfm ../tfm
gftopk rgrrg10.*gf
mv rgrrg10.*pk ../pk
rm rgrrg10.*gf rgrrg10.log
../../../../tools/make1cmfont rgrsl10 0
../../../../tools/make1cmfont rgrti10 0
../../../../tools/make1cmfont rgrbf10 0
../../../../tools/make1cmfont rgrsc10 0
../../../../tools/makecmfont cmg10
../../../../tools/makecmfont cmgb10
../../../../tools/makecmfont cmgi10
../../../../tools/makecmfont cmgtt10
cd ..
